@@ -3,6 +3,12 @@
 
 from __future__ import absolute_import, division, print_function
 
+from typing import Union
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 import warnings
 
 import mando
@@ -11,6 +17,7 @@ from mando.rst_text_formatter import RSTHelpFormatter
 import numpy as np
 import pandas as pd
 from pandas.tseries.frequencies import to_offset
+import typic
 
 from .. import tsutils
 
@@ -161,37 +168,27 @@ def convert_index_cli(
     tsutils.printiso(tsd, tablefmt=tablefmt)
 
 
-@tsutils.validator(
-    to=[str, ["domain", ["datetime", "number"]], 1],
-    epoch=[
-        [
-            str,
-            [
-                "domain",
-                [
-                    "julian",
-                    "reduced",
-                    "modified",
-                    "truncated",
-                    "dublin",
-                    "cnes",
-                    "ccsds",
-                    "lop",
-                    "lilian",
-                    "rata_die",
-                    "mars_sol",
-                    "unix",
-                ],
-            ],
-            1,
-        ],
-        [tsutils.parsedate, ["pass", []], 1],
-    ],
-)
+@typic.al
 def convert_index(
-    to,
+    to: Literal["datetime", "number"],
     interval=None,
-    epoch="julian",
+    epoch: Union[
+        Literal[
+            "julian",
+            "reduced",
+            "modified",
+            "truncated",
+            "dublin",
+            "cnes",
+            "ccsds",
+            "lop",
+            "lilian",
+            "rata_die",
+            "mars_sol",
+            "unix",
+        ],
+        pd.Timestamp,
+    ] = "julian",
     input_ts="-",
     columns=None,
     start_date=None,
@@ -218,9 +215,10 @@ def convert_index(
         nround_index = round_index
 
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts, skiprows=skiprows, names=names, index_type=index_type
-        ),
+        input_ts,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=nstart_date,
         end_date=nend_date,
         pick=columns,
