@@ -5,6 +5,7 @@ from __future__ import absolute_import, division, print_function
 
 import mando
 from mando.rst_text_formatter import RSTHelpFormatter
+import typic
 
 from .. import tsutils
 
@@ -81,10 +82,10 @@ def converttz_cli(
     )
 
 
-@tsutils.validator(fromtz=[str, ["pass", []], 1], totz=[str, ["pass", []], 1])
+@typic.al
 def converttz(
-    fromtz,
-    totz,
+    fromtz: str,
+    totz: str,
     input_ts="-",
     columns=None,
     start_date=None,
@@ -100,9 +101,10 @@ def converttz(
 ):
     """Convert the time zone of the index."""
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts, skiprows=skiprows, names=names, index_type=index_type
-        ),
+        input_ts,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=start_date,
         end_date=end_date,
         pick=columns,
