@@ -2,11 +2,13 @@
 """A lag routine."""
 
 from __future__ import absolute_import, print_function
+from typing import List
 
 import mando
 from mando.rst_text_formatter import RSTHelpFormatter
 
 import pandas as pd
+import typic
 
 from .. import tsutils
 
@@ -70,9 +72,15 @@ def lag_cli(
     )
 
 
-@tsutils.validator(lags=[int, ["pass", []], 1])
+@typic.constrained(ge=0)
+class Lags(int):
+    """'lags' constraint"""
+
+
+@tsutils.transform_args(lags=tsutils.make_list)
+@typic.al
 def lag(
-    lags,
+    lags: List[Lags],
     input_ts="-",
     print_input=False,
     start_date=None,
@@ -87,13 +95,11 @@ def lag(
 ):
     """Create a series of lagged time-series."""
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts,
-            dropna="all",
-            skiprows=skiprows,
-            names=names,
-            index_type=index_type,
-        ),
+        input_ts,
+        dropna="all",
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=start_date,
         end_date=end_date,
         pick=columns,
@@ -101,7 +107,6 @@ def lag(
         target_units=target_units,
         clean=clean,
     )
-    lags = tsutils.make_list(lags)
     if len(lags) == 1:
         lags = lags[0]
     try:
