@@ -3,18 +3,27 @@
 
 from __future__ import absolute_import, division, print_function
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+
 import warnings
 
 import mando
 import numpy as np
 from mando.rst_text_formatter import RSTHelpFormatter
+import typic
 
 from .. import tsutils
 
 warnings.filterwarnings("ignore")
 
 
-def _boolrelextrema(data, comparator, axis=0, order=1, mode="clip"):
+@typic.al
+def _boolrelextrema(
+    data, comparator, axis=0, order: tsutils.IntGreaterEqualToOne = 1, mode="clip"
+):
     """Calculate the relative extrema of `data`.
 
     Relative extrema are calculated by finding locations where
@@ -55,14 +64,11 @@ def _boolrelextrema(data, comparator, axis=0, order=1, mode="clip"):
     [False, False, True, False, False]
 
     """
-    if (int(order) != order) or (order < 1):
-        raise ValueError("Order must be an int >= 1")
-
     datalen = data.shape[axis]
     locs = np.arange(0, datalen)
 
     results = np.ones(data.shape, dtype=bool)
-    main = data.take(locs, axis=axis)
+    main = data.take(locs)
     for shift in range(1, order + 1):
         plus = np.take(data, locs + shift, axis=axis, mode=mode)
         results &= comparator(main, plus)
@@ -195,7 +201,13 @@ def _peakdetect_parabola_fitter(raw_peaks, x_axis, y_axis, points):
     return fitted_peaks
 
 
-def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
+@typic.al
+def _peakdetect(
+    y_axis,
+    x_axis=None,
+    window: tsutils.IntGreaterEqualToOne = 24,
+    delta: tsutils.IntGreaterEqualToZero = 0,
+):
     """Private peak detection algorithm.
 
     Converted from/based on a MATLAB script
@@ -238,12 +250,6 @@ def _peakdetect(y_axis, x_axis=None, window=24, delta=0):
     # store data length for later use
     length = len(y_axis)
 
-    # perform some checks
-    if window < 1:
-        raise ValueError('window must be "1" or above in value')
-    if not (np.isscalar(delta) and delta >= 0):
-        raise ValueError("delta must be a positive number")
-
     # maxima and minima candidates are temporarily stored in
     # mx and mn respectively
     mn, mx = np.Inf, -np.Inf
@@ -669,7 +675,12 @@ def _peakdetect_zero_crossing(y_axis, x_axis=None, window=5):
     return [max_peaks, min_peaks]
 
 
-def _smooth(x, window_len=11, window="hanning"):
+@typic.al
+def _smooth(
+    x,
+    window_len=11,
+    window: Literal["flat", "hanning", "hamming", "bartlett", "blackman"] = "hanning",
+):
     """Smooth the data using a window of the requested size.
 
     This method is based on the convolution of a scaled window on the signal.
@@ -714,9 +725,6 @@ def _smooth(x, window_len=11, window="hanning"):
     if window_len < 3:
         return x
 
-    if window not in ["flat", "hanning", "hamming", "bartlett", "blackman"]:
-        raise ValueError
-
     s = np.r_[x[window_len - 1 : 0 : -1], x, x[-1:-window_len:-1]]
     # print(len(s))
     if window == "flat":  # moving average
@@ -904,14 +912,7 @@ def peak_detection_cli(
     )
 
 
-@tsutils.validator(
-    extrema=[str, ["domain", ["peak", "valley", "both"]], 1],
-    method=[str, ["domain", ["rel", "minmax", "zero_crossing", "parabola", "sine"]], 1],
-    window=[int, ["range", [0, None]], 1],
-    pad_len=[int, ["range", [0, None]], 1],
-    points=[int, ["range", [0, None]], 1],
-    lock_frequency=[bool, ["domain", [True, False]], 1],
-)
+@typic.al
 def peak_detection(
     input_ts="-",
     columns=None,
@@ -922,12 +923,12 @@ def peak_detection(
     index_type="datetime",
     names=None,
     clean=False,
-    method="rel",
-    extrema="peak",
-    window=24,
-    pad_len=5,
-    points=9,
-    lock_frequency=False,
+    method: Literal["rel", "minmax", "zero_crossing", "parabola", "sine"] = "rel",
+    extrema: Literal["peak", "valley", "both"] = "peak",
+    window: tsutils.IntGreaterEqualToOne = 24,
+    pad_len: tsutils.IntGreaterEqualToOne = 5,
+    points: tsutils.IntGreaterEqualToOne = 9,
+    lock_frequency: bool = False,
     round_index=None,
     source_units=None,
     target_units=None,
@@ -937,9 +938,10 @@ def peak_detection(
     # Couldn't get fft method working correctly.  Left pieces in
     # in case want to figure it out in the future.
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts, skiprows=skiprows, names=names, index_type=index_type
-        ),
+        input_ts,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=start_date,
         end_date=end_date,
         pick=columns,
