@@ -2,6 +2,12 @@
 """Collection of functions for the manipulation of time series."""
 
 from __future__ import absolute_import, division, print_function
+from typing import List, Optional, Tuple
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 import itertools
 import os
@@ -9,6 +15,7 @@ import warnings
 
 import mando
 from mando.rst_text_formatter import RSTHelpFormatter
+import typic
 
 import numpy as np
 import pandas as pd
@@ -34,6 +41,22 @@ ldocstrings[
 ldocstrings[
     "yone"
 ] = """Data must be organized as 'index,y1'.  Can only plot one series."""
+ldocstrings[
+    "secondary_axis"
+] = """[optional, default is False]
+
+        * list/tuple: Give the column numbers or names to plot on secondary
+          y-axis.
+        * (string, string): The first string is the units of the primary axis,
+          the second string is the units of the secondary axis if you want just
+          unit conversion.  Use any units or combination thereof from the
+          "pint" library.
+        * (callable, callable): Functions relating relationship between
+          primary and secondary axis.  First function will be given the values
+          on primary axis and returns valueis on secondary axis.  Second function
+          will be do the inverse.  Python API only.
+        * string: One of pre-built (callable, callable) combinations.  Can be
+          one of "period"."""
 
 MARKER_LIST = [
     ".",
@@ -140,6 +163,7 @@ def plot_cli(
     end_date=None,
     clean=False,
     skiprows=None,
+    dropna="no",
     index_type="datetime",
     names=None,
     ofilename="plot.png",
@@ -165,6 +189,7 @@ def plot_cli(
     xlim=None,
     ylim=None,
     secondary_y=False,
+    secondary_x=False,
     mark_right=True,
     scatter_matrix_diagonal="kde",
     bootstrap_size=50,
@@ -192,20 +217,20 @@ def plot_cli(
     hlines_y=None,
     hlines_xmin=None,
     hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
+    hlines_colors="auto",
+    hlines_linestyles="auto",
     vlines_x=None,
     vlines_ymin=None,
     vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
+    vlines_colors="auto",
+    vlines_linestyles="auto",
 ):
     r"""Plot data.
 
     Parameters
     ----------
     {input_ts}
-    ofilename : str
+    ofilename : str, optional
         [optional, defaults to 'plot.png']
 
         Output filename for the plot.  Extension defines
@@ -214,7 +239,12 @@ def plot_cli(
         If used within Python, and `ofilename` is None will return the
         Matplotlib figure that can then be changed or added to as
         needed.
-    type : str
+    type : {'time', 'xy', 'double_mass', 'bloxplot', 'scatter_matrix',
+            'lag_plot', 'autocorrelation', 'bootstrap', 'histogram', 'kde',
+            'kde_time', 'bar', 'barh', 'bar_stacked', 'barh_stacked',
+            'heatmap', 'norm_xaxis', 'norm_yaxis', 'lognorm_xaxis',
+            'lognorm_yaxis', 'weibull_xaxis', 'weibull_yaxis', 'taylor',
+            'target'}, optional
         [optional, defaults to 'time']
 
         The plot type.
@@ -318,7 +348,7 @@ def plot_cli(
             calculated and displayed are bias, root mean square deviation, and
             centered root mean square deviation.  The data columns have to be
             organized as 'observed,simulated1,simulated2,simulated3,...etc.'
-    lag_plot_lag
+    lag_plot_lag : int, optional
         [optional, default to 1]
 
         The lag used if ``type`` "lag_plot" is chosen.
@@ -499,7 +529,7 @@ def plot_cli(
         +-------+----------------+
         | d     | thin diamond   |
         +-------+----------------+
-        | _     | hlines_y          |
+        | _     | hlines_y       |
         +-------+----------------+
         | None  | nothing        |
         +-------+----------------+
@@ -577,10 +607,9 @@ def plot_cli(
 
         Defines the type of the yaxis.  One of 'arithmetic', 'log'.
     secondary_y
-        [optional, default is False]
-
-        Whether to plot on the secondary y-axis. If a list/tuple, which
-        time-series to plot on secondary y-axis.
+        {secondary_axis}
+    secondary_x
+        {secondary_axis}
     mark_right
         [optional, default is True]
 
@@ -668,6 +697,7 @@ def plot_cli(
     {end_date}
     {clean}
     {skiprows}
+    {dropna}
     {index_type}
     {names}
     {source_units}
@@ -719,19 +749,31 @@ def plot_cli(
     hlines_xmin:
         [optional, defaults to None]
 
-        List of minimum x values to start the horizontal line.  If a list must be same length as `hlines_y`.  If a single number will be used as the minimum x values for all horizontal lines.  A missing value or None will start at the minimum x value for the entire plot.
+        List of minimum x values to start the horizontal line.  If a list must
+        be same length as `hlines_y`.  If a single number will be used as the
+        minimum x values for all horizontal lines.  A missing value or None
+        will start at the minimum x value for the entire plot.
     hlines_xmax:
         [optional, defaults to None]
 
-        List of maximum x values to end each horizontal line.  If a list must be same length as `hlines_y`.  If a single number will be the maximum x value for all horizontal lines.  A missing value or None will end at the maximum x value for the entire plot.
+        List of maximum x values to end each horizontal line.  If a list must
+        be same length as `hlines_y`.  If a single number will be the maximum
+        x value for all horizontal lines.  A missing value or None will end at
+        the maximum x value for the entire plot.
     hlines_colors:
         [optional, defaults to None]
 
-        List of colors for the horizontal lines.  If a single color then will be used as the color for all horizontal lines.  If a list must be same length as `hlines_y`.  If None will take from the color pallette in the current plot style.
+        List of colors for the horizontal lines.  If a single color then will
+        be used as the color for all horizontal lines.  If a list must be same
+        length as `hlines_y`.  If None will take from the color pallette in the
+        current plot style.
     hlines_linestyles:
         [optional, defaults to None]
 
-        List of linestyles for the horizontal lines.  If a single linestyle then will be used as the linestyle for all horizontal lines.  If a list must be same length as `hlines_y`.  If None will take for the standard linestyles list.
+        List of linestyles for the horizontal lines.  If a single linestyle
+        then will be used as the linestyle for all horizontal lines.  If a list
+        must be same length as `hlines_y`.  If None will take for the standard
+        linestyles list.
     vlines_x:
         [optional, defaults to None]
 
@@ -739,27 +781,41 @@ def plot_cli(
     vlines_ymin:
         [optional, defaults to None]
 
-        List of minimum y values to start the vertical line.  If a list must be same length as `vlines_x`.  If a single number will be used as the minimum x values for all vertical lines.  A missing value or None will start at the minimum x value for the entire plot.
+        List of minimum y values to start the vertical line.  If a list must be
+        same length as `vlines_x`.  If a single number will be used as the
+        minimum x values for all vertical lines.  A missing value or None will
+        start at the minimum x value for the entire plot.
     vlines_ymax:
         [optional, defaults to None]
 
-        List of maximum x values to end each vertical line.  If a list must be same length as `vlines_x`.  If a single number will be the maximum x value for all vertical lines.  A missing value or None will end at the maximum x value for the entire plot.
+        List of maximum x values to end each vertical line.  If a list must be
+        same length as `vlines_x`.  If a single number will be the maximum
+        x value for all vertical lines.  A missing value or None will end at
+        the maximum x value for the entire plot.
     vlines_colors:
         [optional, defaults to None]
 
-        List of colors for the vertical lines.  If a single color then will be used as the color for all vertical lines.  If a list must be same length as `vlines_x`.  If None will take from the color pallette in the current plot style.
+        List of colors for the vertical lines.  If a single color then will be
+        used as the color for all vertical lines.  If a list must be same
+        length as `vlines_x`.  If None will take from the color pallette in the
+        current plot style.
     vlines_linestyles:
         [optional, defaults to None]
 
-        List of linestyles for the vertical lines.  If a single linestyle then will be used as the linestyle for all vertical lines.  If a list must be same length as `vlines_x`.  If None will take for the standard linestyles list.
-        """
+        List of linestyles for the vertical lines.  If a single linestyle then
+        will be used as the linestyle for all vertical lines.  If a list must
+        be same length as `vlines_x`.  If None will take for the standard
+        linestyles list.
+    """
+
     plt = plot(
-        input_ts=input_ts,
+        input_ts="-",
         columns=columns,
         start_date=start_date,
         end_date=end_date,
         clean=clean,
         skiprows=skiprows,
+        dropna=dropna,
         index_type=index_type,
         names=names,
         ofilename=ofilename,
@@ -785,6 +841,7 @@ def plot_cli(
         xlim=xlim,
         ylim=ylim,
         secondary_y=secondary_y,
+        secondary_x=secondary_x,
         mark_right=mark_right,
         scatter_matrix_diagonal=scatter_matrix_diagonal,
         bootstrap_size=bootstrap_size,
@@ -822,145 +879,42 @@ def plot_cli(
     )
 
 
-@tsutils.validator(
-    ofilename=[str, ["pass", []], 1],
-    type=[
-        str,
-        [
-            "domain",
-            [
-                "time",
-                "xy",
-                "double_mass",
-                "boxplot",
-                "scatter_matrix",
-                "lag_plot",
-                "autocorrelation",
-                "bootstrap",
-                "histogram",
-                "kde",
-                "kde_time",
-                "bar",
-                "barh",
-                "bar_stacked",
-                "barh_stacked",
-                "heatmap",
-                "norm_xaxis",
-                "norm_yaxis",
-                "lognorm_yaxis",
-                "lognorm_xaxis",
-                "weibull_xaxis",
-                "weibull_yaxis",
-                "taylor",
-                "target",
-                "probability_density",
-            ],
-        ],
-        1,
-    ],
-    lag_plot_lag=[int, ["range", [1, None]], 1],
-    xtitle=[str, ["pass", []], 1],
-    ytitle=[str, ["pass", []], 1],
-    title=[str, ["pass", []], 1],
-    figsize=[float, ["range", [0, None]], 2],
-    legend=[bool, ["domain", [True, False]], 1],
-    legend_names=[str, ["pass", []], 1],
-    subplots=[bool, ["domain", [True, False]], 1],
-    sharex=[bool, ["domain", [True, False]], 1],
-    sharey=[bool, ["domain", [True, False]], 1],
-    colors=[str, ["pass", []], None],
-    linestyles=[str, ["domain", ["auto", None, "", " ", "  "] + LINE_LIST], None],
-    markerstyles=[str, ["domain", ["auto", None, "", " ", "  "] + MARKER_LIST], None],
-    bar_hatchstyles=[str, ["domain", ["auto", None, "", " ", "  "] + HATCH_LIST], None],
-    style=[str, ["pass", []], None],
-    xlim=[float, ["pass", []], 2],
-    ylim=[float, ["pass", []], 2],
-    xaxis=[str, ["domain", ["arithmetic", "log"]], 1],
-    yaxis=[str, ["domain", ["arithmetic", "log"]], 1],
-    secondary_y=[bool, ["domain", [True, False]], 1],
-    mark_right=[bool, ["domain", [True, False]], 1],
-    scatter_matrix_diagonal=[str, ["domain", ["kde", "hist"]], 1],
-    bootstrap_size=[int, ["range", [0, None]], 1],
-    xy_match_line=[str, ["pass", []], 1],
-    grid=[bool, ["domain", [True, False]], 1],
-    label_rotation=[float, ["pass", []], 1],
-    label_skip=[int, ["range", [1, None]], 1],
-    drawstyle=[str, ["pass", []], 1],
-    por=[bool, ["domain", [True, False]], 1],
-    invert_xaxis=[bool, ["domain", [True, False]], 1],
-    invert_yaxis=[bool, ["domain", [True, False]], 1],
-    plotting_position=[
-        str,
-        [
-            "domain",
-            ["weibull", "benard", "tukey", "gumbel", "hazen", "cunnane", "california"],
-        ],
-        1,
-    ],
-    prob_plot_sort_values=[str, ["domain", ["ascending", "descending"]], 1],
-    plot_styles=[
-        str,
-        [
-            "domain",
-            [
-                "classic",
-                "Solarize_Light2",
-                "bmh",
-                "dark_background",
-                "fast",
-                "fivethirtyeight",
-                "ggplot",
-                "grayscale",
-                "seaborn",
-                "seaborn-bright",
-                "seaborn-colorblind",
-                "seaborn-dark",
-                "seaborn-dark-palette",
-                "seaborn-darkgrid",
-                "seaborn-deep",
-                "seaborn-muted",
-                "seaborn-notebook",
-                "seaborn-paper",
-                "seaborn-pastel",
-                "seaborn-poster",
-                "seaborn-talk",
-                "seaborn-ticks",
-                "seaborn-white",
-                "seaborn-whitegrid",
-                "tableau-colorblind10",
-                "science",
-                "grid",
-                "ieee",
-                "scatter",
-                "notebook",
-                "high-vis",
-                "bright",
-                "vibrant",
-                "muted",
-                "retro",
-            ],
-        ],
-        None,
-    ],
-    hlines_y=[float, ["pass", []], None],
-    hlines_xmin=[float, ["pass", []], None],
-    hlines_xmax=[float, ["pass", []], None],
-    hlines_colors=[str, ["pass", []], None],
-    hlines_linestyles=[
-        str,
-        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
-        None,
-    ],
-    vlines_x=[float, ["pass", []], None],
-    vlines_ymin=[float, ["pass", []], None],
-    vlines_ymax=[float, ["pass", []], None],
-    vlines_colors=[str, ["pass", []], None],
-    vlines_linestyles=[
-        str,
-        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
-        None,
-    ],
+#    linestyles=[str, ["domain", ["auto", None, "", " ", "  "] + LINE_LIST], None],
+#    markerstyles=[str, ["domain", ["auto", None, "", " ", "  "] + MARKER_LIST], None],
+#    bar_hatchstyles=[str, ["domain", ["auto", None, "", " ", "  "] + HATCH_LIST], None],
+#    hlines_linestyles=[
+#        str,
+#        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
+#        None,
+#    ],
+#    vlines_linestyles=[
+#        str,
+#        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
+#        None,
+#    ],
+@tsutils.transform_args(
+    xlim=tsutils.make_list,
+    ylim=tsutils.make_list,
+    legend_names=tsutils.make_list,
+    markerstyles=tsutils.make_list,
+    colors=tsutils.make_list,
+    linestyles=tsutils.make_list,
+    bar_hatchstyles=tsutils.make_list,
+    style=tsutils.make_list,
+    figsize=tsutils.make_list,
+    hlines_y=tsutils.make_list,
+    hlines_xmin=tsutils.make_list,
+    hlines_xmax=tsutils.make_list,
+    hlines_colors=tsutils.make_list,
+    hlines_linestyles=tsutils.make_list,
+    vlines_x=tsutils.make_list,
+    vlines_ymin=tsutils.make_list,
+    vlines_ymax=tsutils.make_list,
+    vlines_colors=tsutils.make_list,
+    vlines_linestyles=tsutils.make_list,
+    plot_styles=tsutils.make_list,
 )
+@typic.al
 def plot(
     input_ts="-",
     columns=None,
@@ -968,65 +922,133 @@ def plot(
     end_date=None,
     clean=False,
     skiprows=None,
+    dropna="no",
     index_type="datetime",
     names=None,
-    ofilename="plot.png",
-    type="time",
-    xtitle="",
-    ytitle="",
-    title="",
-    figsize="10,6.0",
-    legend=None,
-    legend_names=None,
-    subplots=False,
-    sharex=True,
-    sharey=False,
-    colors="auto",
-    linestyles="auto",
-    markerstyles=" ",
-    bar_hatchstyles="auto",
-    style="auto",
-    logx=False,
-    logy=False,
-    xaxis="arithmetic",
-    yaxis="arithmetic",
-    xlim=None,
-    ylim=None,
+    ofilename: Optional[str] = "plot.png",
+    type: Literal[
+        "time",
+        "xy",
+        "double_mass",
+        "boxplot",
+        "scatter_matrix",
+        "lag_plot",
+        "autocorrelation",
+        "bootstrap",
+        "histogram",
+        "kde",
+        "kde_time",
+        "bar",
+        "barh",
+        "bar_stacked",
+        "barh_stacked",
+        "heatmap",
+        "norm_xaxis",
+        "norm_yaxis",
+        "lognorm_yaxis",
+        "lognorm_xaxis",
+        "weibull_xaxis",
+        "weibull_yaxis",
+        "taylor",
+        "target",
+        "probability_density",
+    ] = "time",
+    xtitle: str = "",
+    ytitle: str = "",
+    title: str = "",
+    figsize: Tuple[float, float] = "10,6.0",
+    legend: Optional[bool] = None,
+    legend_names: Optional[List[str]] = None,
+    subplots: bool = False,
+    sharex: bool = True,
+    sharey: bool = False,
+    colors: Optional[List[Optional[str]]] = "auto",
+    linestyles: Optional[List[Optional[str]]] = "auto",
+    markerstyles: Optional[List[Optional[str]]] = " ",
+    bar_hatchstyles: Optional[List[Optional[str]]] = "auto",
+    style: Optional[List[str]] = "auto",
+    logx: bool = False,
+    logy: bool = False,
+    xaxis: Literal["arithmetic", "log"] = "arithmetic",
+    yaxis: Literal["arithmetic", "log"] = "arithmetic",
+    xlim: Optional[Tuple[Optional[float], Optional[float]]] = None,
+    ylim: Optional[Tuple[Optional[float], Optional[float]]] = None,
     secondary_y=False,
-    mark_right=True,
-    scatter_matrix_diagonal="kde",
-    bootstrap_size=50,
-    bootstrap_samples=500,
-    norm_xaxis=False,
-    norm_yaxis=False,
-    lognorm_xaxis=False,
-    lognorm_yaxis=False,
-    xy_match_line="",
-    grid=False,
-    label_rotation=None,
-    label_skip=1,
-    force_freq=None,
-    drawstyle="default",
-    por=False,
-    invert_xaxis=False,
-    invert_yaxis=False,
+    secondary_x=False,
+    mark_right: bool = True,
+    scatter_matrix_diagonal: Literal["kde", "hist"] = "kde",
+    bootstrap_size: tsutils.IntGreaterEqualToOne = 50,
+    bootstrap_samples: tsutils.IntGreaterEqualToOne = 500,
+    norm_xaxis: bool = False,
+    norm_yaxis: bool = False,
+    lognorm_xaxis: bool = False,
+    lognorm_yaxis: bool = False,
+    xy_match_line: str = "",
+    grid: bool = False,
+    label_rotation: Optional[float] = None,
+    label_skip: tsutils.IntGreaterEqualToOne = 1,
+    force_freq: Optional[str] = None,
+    drawstyle: str = "default",
+    por: bool = False,
+    invert_xaxis: bool = False,
+    invert_yaxis: bool = False,
     round_index=None,
-    plotting_position="weibull",
-    prob_plot_sort_values="descending",
+    plotting_position: Literal[
+        "weibull", "benard", "tukey", "gumbel", "hazen", "cunnane", "california"
+    ] = "weibull",
+    prob_plot_sort_values: Literal["ascending", "descending"] = "descending",
     source_units=None,
     target_units=None,
-    lag_plot_lag=1,
-    plot_styles="bright",
-    hlines_y=None,
-    hlines_xmin=None,
-    hlines_xmax=None,
-    hlines_colors=None,
-    hlines_linestyles="-",
-    vlines_x=None,
-    vlines_ymin=None,
-    vlines_ymax=None,
-    vlines_colors=None,
-    vlines_linestyles="-",
+    lag_plot_lag: tsutils.IntGreaterEqualToOne = 1,
+    plot_styles: List[
+        Literal[
+            "classic",
+            "Solarize_Light2",
+            "bmh",
+            "dark_background",
+            "fast",
+            "fivethirtyeight",
+            "ggplot",
+            "grayscale",
+            "seaborn",
+            "seaborn-bright",
+            "seaborn-colorblind",
+            "seaborn-dark",
+            "seaborn-dark-palette",
+            "seaborn-darkgrid",
+            "seaborn-deep",
+            "seaborn-muted",
+            "seaborn-notebook",
+            "seaborn-paper",
+            "seaborn-pastel",
+            "seaborn-poster",
+            "seaborn-talk",
+            "seaborn-ticks",
+            "seaborn-white",
+            "seaborn-whitegrid",
+            "tableau-colorblind10",
+            "science",
+            "grid",
+            "ieee",
+            "scatter",
+            "notebook",
+            "high-vis",
+            "bright",
+            "vibrant",
+            "muted",
+            "retro",
+        ]
+    ] = "bright",
+    hlines_y: Optional[List[float]] = None,
+    hlines_xmin: Optional[List[float]] = None,
+    hlines_xmax: Optional[List[float]] = None,
+    hlines_colors: List[str] = "auto",
+    hlines_linestyles: List[Optional[str]] = "auto",
+    vlines_x: Optional[List[float]] = None,
+    vlines_ymin: Optional[List[float]] = None,
+    vlines_ymax: Optional[List[float]] = None,
+    vlines_colors: List[str] = "auto",
+    vlines_linestyles: List[Optional[str]] = "auto",
 ):
     r"""Plot data."""
     # Need to work around some old option defaults with the implementation of
@@ -1040,17 +1062,19 @@ def plot(
     from matplotlib.ticker import FixedLocator
 
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts, skiprows=skiprows, names=names, index_type=index_type
-        ),
+        input_tsd=input_ts,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=start_date,
         end_date=end_date,
         pick=columns,
         round_index=round_index,
-        dropna="all",
+        dropna=dropna,
         source_units=source_units,
         target_units=target_units,
         clean=clean,
+        por=por,
     )
 
     if type in ["bootstrap", "heatmap", "autocorrelation", "lag_plot"]:
@@ -1066,15 +1090,6 @@ The DataFrame that you supplied has {0} time-series.
                 )
             )
 
-    if por is True:
-        tsd = tsutils.common_kwds(
-            tsutils.read_iso_ts(tsd),
-            start_date=start_date,
-            end_date=end_date,
-            round_index=round_index,
-            dropna="no",
-        )
-
     # This is to help pretty print the frequency
     try:
         try:
@@ -1094,7 +1109,7 @@ The DataFrame that you supplied has {0} time-series.
         short_freq = ""
 
     if legend_names:
-        lnames = tsutils.make_list(legend_names)
+        lnames = legend_names
         if len(lnames) != len(set(lnames)):
             raise ValueError(
                 tsutils.error_wrapper(
@@ -1130,31 +1145,28 @@ l1,l2,l3,...  where l1 is the legend for x1,y1, l2 is the legend for x2,y2,
     else:
         lnames = tsd.columns
 
-    if colors == "auto":
-        colors = None
-    else:
-        colors = tsutils.make_list(colors)
+    if colors is not None:
+        if "auto" in colors:
+            colors = None
 
-    if linestyles == "auto":
+    if linestyles is None:
+        linestyles = " "
+    elif "auto" in linestyles:
         linestyles = LINE_LIST
-    else:
-        linestyles = tsutils.make_list(linestyles)
 
-    if bar_hatchstyles == "auto":
+    if bar_hatchstyles is None:
+        bar_hatchstyles = " "
+    elif "auto" in bar_hatchstyles:
         bar_hatchstyles = HATCH_LIST
-    else:
-        bar_hatchstyles = tsutils.make_list(bar_hatchstyles)
 
-    if markerstyles == "auto":
+    if markerstyles is None:
+        markerstyles = " "
+    elif "auto" in markerstyles:
         markerstyles = MARKER_LIST
-    else:
-        markerstyles = tsutils.make_list(markerstyles)
-        if markerstyles is None:
-            markerstyles = " "
 
-    if style != "auto":
+    if "auto" not in style:
 
-        nstyle = tsutils.make_list(style)
+        nstyle = style
         if len(nstyle) != len(tsd.columns):
             raise ValueError(
                 tsutils.error_wrapper(
@@ -1262,8 +1274,7 @@ The {0} setting for yaxis is ignored.
 
     xlim = _know_your_limits(xlim, axis=xaxis)
     ylim = _know_your_limits(ylim, axis=yaxis)
-
-    plot_styles = tsutils.make_list(plot_styles) + ["no-latex"]
+    plot_styles = plot_styles + ["no-latex"]
     style_loc = os.path.join(
         os.path.dirname(__file__), os.pardir, "SciencePlots_styles"
     )
@@ -1275,7 +1286,6 @@ The {0} setting for yaxis is ignored.
     ]
     plt.style.use(plot_styles)
 
-    figsize = tsutils.make_list(figsize, n=2)
     _, ax = plt.subplots(figsize=figsize)
 
     if not isinstance(tsd.index, pd.DatetimeIndex):
@@ -1332,7 +1342,7 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
         }
 
     if type == "time":
-        ax = tsd.plot(
+        tsd.plot(
             legend=legend,
             subplots=subplots,
             sharex=sharex,
@@ -1341,10 +1351,10 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             logy=logy,
             xlim=xlim,
             ylim=ylim,
-            secondary_y=secondary_y,
             mark_right=mark_right,
             figsize=figsize,
             drawstyle=drawstyle,
+            ax=ax,
         )
         for index, line in enumerate(ax.lines):
             if icolors is not None:
@@ -1406,12 +1416,14 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             else:
                 ndf = tsd.iloc[:, colindex * 2 : colindex * 2 + 2]
 
+            ndf = ndf.dropna()
+
             if type == "double_mass":
-                ndf = ndf.dropna()
                 ndf.iloc[:, 0] = ndf.iloc[:, 0].cumsum()
                 ndf.iloc[:, 1] = ndf.iloc[:, 1].cumsum()
-            oxdata = np.array(ndf.iloc[:, 0])
-            oydata = np.array(ndf.iloc[:, 1])
+
+            oxdata = np.squeeze(ndf.iloc[:, 0].values)
+            oydata = np.squeeze(ndf.iloc[:, 1].values)
 
             if icolors is not None:
                 c = next(icolors)
@@ -1532,7 +1544,6 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             logy=logy,
             xlim=xlim,
             ylim=ylim,
-            secondary_y=secondary_y,
             figsize=figsize,
         )
         for index, line in enumerate(ax.lines):
@@ -1575,7 +1586,6 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             logy=logy,
             xlim=xlim,
             ylim=ylim,
-            secondary_y=secondary_y,
             mark_right=mark_right,
             figsize=figsize,
             drawstyle=drawstyle,
@@ -1629,19 +1639,21 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
     elif type == "scatter_matrix":
         from pandas.plotting import scatter_matrix
 
+        tsd = tsd.dropna()
+
         if scatter_matrix_diagonal == "probablity_density":
             scatter_matrix_diagonal = "kde"
         scatter_matrix(tsd, diagonal=scatter_matrix_diagonal, figsize=figsize)
     elif type == "lag_plot":
         from pandas.plotting import lag_plot
 
-        lag_plot(tsd, lag=lag_plot_lag, ax=ax)
+        lag_plot(tsd.dropna(), lag=lag_plot_lag, ax=ax)
         xtitle = xtitle or "y(t)"
         ytitle = ytitle or "y(t+{0})".format(short_freq or 1)
     elif type == "autocorrelation":
         from pandas.plotting import autocorrelation_plot
 
-        autocorrelation_plot(tsd, ax=ax)
+        autocorrelation_plot(tsd.dropna(), ax=ax)
         xtitle = xtitle or "Time Lag {0}".format(short_freq)
     elif type == "bootstrap":
         from pandas.plotting import bootstrap_plot
@@ -1665,7 +1677,7 @@ The "heatmap" plot type can only work with daily time series.
         dr = pd.date_range(
             "{0}-01-01".format(byear), "{0}-12-31".format(eyear), freq="D"
         )
-        ntsd = tsd.reindex(index=dr)
+        ntsd = tsd.reindex(index=dr).astype("Float64")
         groups = ntsd.iloc[:, 0].groupby(pd.Grouper(freq="A"))
         years = pd.DataFrame()
         for name, group in groups:
@@ -1698,10 +1710,10 @@ The "heatmap" plot type can only work with daily time series.
         grid = False
     elif type in ("bar", "bar_stacked", "barh", "barh_stacked"):
         stacked = False
-        if type[-7:] == "stacked":
+        if "stacked" in type:
             stacked = True
         kind = "bar"
-        if type[:4] == "barh":
+        if "barh" in type:
             kind = "barh"
         if icolors is not None:
             c = [next(icolors) for i in range(len(tsd.columns))]
@@ -1716,7 +1728,6 @@ The "heatmap" plot type can only work with daily time series.
             logy=logy,
             xlim=xlim,
             ylim=ylim,
-            figsize=figsize,
             linestyle=None,
             color=c,
         )
@@ -1755,28 +1766,18 @@ The "heatmap" plot type can only work with daily time series.
     elif type == "histogram":
         tsd.hist(figsize=figsize, sharey=sharey, sharex=sharex)
 
-    if hlines_y is not None:
-        hlines_y = tsutils.make_list(hlines_y)
-        hlines_xmin = tsutils.make_list(hlines_xmin)
-        hlines_xmax = tsutils.make_list(hlines_xmax)
-        hlines_colors = tsutils.make_list(hlines_colors)
-        hlines_linestyles = tsutils.make_list(hlines_linestyles)
-        nxlim = ax.get_xlim()
-        if hlines_xmin is None:
-            hlines_xmin = nxlim[0]
-        if hlines_xmax is None:
-            hlines_xmax = nxlim[1]
-    if vlines_x is not None:
-        vlines_x = tsutils.make_list(vlines_x)
-        vlines_ymin = tsutils.make_list(vlines_ymin)
-        vlines_ymax = tsutils.make_list(vlines_ymax)
-        vlines_colors = tsutils.make_list(vlines_colors)
-        vlines_linestyles = tsutils.make_list(vlines_linestyles)
-        nylim = ax.get_ylim()
-        if vlines_ymin is None:
-            vlines_ymin = nylim[0]
-        if vlines_ymax is None:
-            vlines_ymax = nylim[1]
+    #    if hlines_y is not None:
+    #        hlines_y = tsutils.make_list(hlines_y)
+    #        hlines_xmin = tsutils.make_list(hlines_xmin)
+    #        hlines_xmax = tsutils.make_list(hlines_xmax)
+    #        hlines_colors = tsutils.make_list(hlines_colors)
+    #        hlines_linestyles = tsutils.make_list(hlines_colors)
+    #    if vlines_x is not None:
+    #        vlines_x = tsutils.make_list(vlines_x)
+    #        vlines_ymin = tsutils.make_list(vlines_ymin)
+    #        vlines_ymax = tsutils.make_list(vlines_ymax)
+    #        vlines_colors = tsutils.make_list(vlines_colors)
+    #        vlines_linestyles = tsutils.make_list(vlines_colors)
     if type in [
         "time",
         "xy",
@@ -1792,17 +1793,35 @@ The "heatmap" plot type can only work with daily time series.
     ]:
         if hlines_y is not None:
             if type in ["norm_yaxis", "lognorm_yaxis", "weibull_yaxis"]:
-                hlines_y = ppf(tsutils.make_list(hlines_y))
-            plt.hlines(
-                hlines_y,
-                hlines_xmin,
-                hlines_xmax,
-                colors=hlines_colors,
-                linestyles=hlines_linestyles,
-            )
+                hlines_y = ppf(hlines_y)
+            if hlines_xmin is None:
+                hlines_xmin = ax.get_xlim()[0]
+            if hlines_xmax is None:
+                hlines_xmax = ax.get_xlim()[1]
+            if hlines_colors == "auto":
+                hlines_colors = icolors
+            else:
+                hlines_colors = itertools.cycle(hlines_colors)
+            if hlines_linestyles == "auto":
+                hlines_linestyles = ax._get_lines.prop_cycler
+            else:
+                hlines_linestyles = itertools.cycle(hlines_linestyles)
+            for index, line in enumerate(hlines_y):
+                try:
+                    val = hlines_xmin[index]
+                except KeyError:
+                    hlines_xmin.append(hlines_xmin[-1])
+                try:
+                    val = hlines_xmax[index]
+                except KeyError:
+                    hlines_xmax.append(hlines_xmax[-1])
+            for l, xmin, xmax, c, ls in zip(
+                hlines_y, hlines_xmin, hlines_xmax, hlines_colors, hlines_linestyles
+            ):
+                ax.plot([xmin, l], [xmax, l], colors=c, linestyles=l)
         if vlines_x is not None:
             if type in ["norm_xaxis", "lognorm_xaxis", "weibull_xaxis"]:
-                vlines_x = ppf(tsutils.make_list(vlines_x))
+                vlines_x = ppf(vlines_x)
             plt.vlines(
                 vlines_x,
                 vlines_ymin,
