@@ -3,19 +3,25 @@
 
 from __future__ import absolute_import, division, print_function
 
+from argparse import RawTextHelpFormatter
+import os
 import warnings
 
 import mando
-from mando.rst_text_formatter import RSTHelpFormatter
-
 import pandas as pd
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+import typic
+
 from .. import tsutils
 
 warnings.filterwarnings("ignore")
 
 
-@mando.command("read", formatter_class=RSTHelpFormatter, doctype="numpy")
+@mando.command("read", formatter_class=RawTextHelpFormatter)
 @tsutils.doc(tsutils.docstrings)
 def read_cli(
     force_freq=None,
@@ -52,11 +58,10 @@ def read_cli(
     append : str
         [optional, default is 'columns']
 
-        The type of appending to do.  For "combine" option matching
-        column indices will append rows, matching row indices will
-        append columns, and matching column/row indices use the value
-        from the first dataset.  You can use "row" or "column" to force
-        an append along either axis.
+        The type of appending to do.  For "combine" option matching column
+        indices will append rows, matching row indices will append columns, and
+        matching column/row indices use the value from the first dataset.  You
+        can use "row" or "column" to force an append along either axis.
     {force_freq}
 
         {pandas_offset_codes}
@@ -98,15 +103,11 @@ def read_cli(
     )
 
 
-@tsutils.validator(
-    filenames=[str, ["pass", []], None],
-    append=[str, ["domain", ["columns", "rows", "combine"]], 1],
-    force_freq=[str, ["pass", []], 1],
-)
+@typic.al
 def read(
     *filenames,
     force_freq=None,
-    append="columns",
+    append: Literal["columns", "rows", "combine"] = "columns",
     columns=None,
     start_date=None,
     end_date=None,
@@ -120,60 +121,46 @@ def read(
     round_index=None,
 ):
     """Collect time series from a list of pickle or csv files."""
-    if append not in ["combine", "rows", "columns"]:
-        raise ValueError(
-            tsutils.error_wrapper(
-                """
-The "append" keyword must be "combine", "rows", or "columns".
-
-You game me {0}.
-""".format(
-                    append
-                )
-            )
-        )
-
     if force_freq is not None:
         dropna = "no"
 
-    filenames = tsutils.make_list(filenames)
-    result = pd.DataFrame()
-    result_list = []
-    zones = set()
-    for i in filenames:
-        tsd = tsutils.common_kwds(
-            tsutils.read_iso_ts(
-                i, skiprows=skiprows, names=names, index_type=index_type
-            ),
-            start_date=start_date,
-            end_date=end_date,
-            pick=columns,
-            round_index=round_index,
-            dropna=dropna,
-            force_freq=force_freq,
-            clean=clean,
-            source_units=source_units,
-            target_units=target_units,
+    # # Check for older style where comma delimited list of only files.
+    # # If so, rework as space delimited.
+    isspacedelimited = False
+    for fname in tsutils.make_list(filenames, sep=","):
+        if not os.path.exists(fname):
+            isspacedelimited = True
+            break
+    if isspacedelimited is True:
+        filenames = tsutils.make_list(filenames, sep=" ")
+    else:
+        # All filenames are real files.  Therefore old style and just make
+        # a simple list.
+        filenames = tsutils.make_list(filenames, sep=",")
+        warnings.warn(
+            tsutils.error_wrapper(
+                """
+Using "," separated files is deprecated in favor of space delimited files."""
+            )
         )
-        result_list.append(tsd)
-        zones.add(tsd.index.tzinfo)
 
-    for res in result_list:
-        if len(zones) != 1:
-            try:
-                res.index = res.index.tz_convert(None)
-            except TypeError:
-                pass
+    tsd = tsutils.common_kwds(
+        input_tsd=filenames,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
+        start_date=start_date,
+        end_date=end_date,
+        round_index=round_index,
+        dropna=dropna,
+        force_freq=force_freq,
+        clean=clean,
+        source_units=source_units,
+        target_units=target_units,
+        usecols=columns,
+    )
 
-        if append == "combine":
-            result = result.combine_first(res)
-
-    if append != "combine":
-        result = pd.concat(result_list, axis=append)
-
-    result.sort_index(inplace=True)
-
-    return result
+    return tsd
 
 
 read.__doc__ = read_cli.__doc__
