@@ -2,11 +2,13 @@
 """Collection of functions for the manipulation of time series."""
 
 from __future__ import absolute_import, division, print_function
+from typing import List, Optional, Union
 
 import warnings
 
 import mando
 from mando.rst_text_formatter import RSTHelpFormatter
+import typic
 
 import pandas as pd
 from sklearn import linear_model
@@ -68,7 +70,7 @@ def regression_cli(
     print_input=False,
     tablefmt="csv",
 ):
-    """Regression of one or more time-series against other time-series.
+    """Regression of one or more time-series or indices to a time-series.
 
     If optional ``x_pred_cols`` is given will return a time-series of the ``y``
     predictions. Otherwise returns dictionary of equation and statistics about
@@ -77,7 +79,8 @@ def regression_cli(
     Parameters
     ----------
     method: str
-        The method of regression.
+        The method of regression.  The chosen method will use `x_train_cols` as the
+        independent data and `y_pred_col` as the dependent data.
 
         ARD
             Requires lots of memory.
@@ -176,8 +179,9 @@ def regression_cli(
             (or L1 median) is calculated of all least square solutions.
     x_train_cols: str or list
         List of column names/numbers that hold the ``x`` value datasets used to
-        train the regression..  Perform a multiple regression if ``method``
-        allows by giving several ``x_train_cols``.
+        train the regression.  Perform a multiple regression if ``method``
+        allows by giving several ``x_train_cols``.  To include the index in the
+        regression use column 0 or the index name.
     y_train_col: str or list
         Column name or number of the ``y`` dataset used to train the
         regression.
@@ -227,12 +231,20 @@ def regression_cli(
     )
 
 
-@tsutils.validator(method=[str, ["domain", _FUNCS.keys()], None],)
+# @tsutils.validator(
+#    method=[str, ["domain", _FUNCS.keys()], None],
+# )
+@tsutils.transform_args(
+    x_train_cols=tsutils.make_list,
+    y_train_col=tsutils.make_list,
+    x_pred_cols=tsutils.make_list,
+)
+@typic.al
 def regression(
     method,
-    x_train_cols,
-    y_train_col,
-    x_pred_cols=None,
+    x_train_cols: List[Union[str, int]],
+    y_train_col: List[Union[str, int]],
+    x_pred_cols: Optional[List[Union[str, int]]] = None,
     input_ts="-",
     columns=None,
     start_date=None,
@@ -246,8 +258,6 @@ def regression(
     print_input=False,
 ):
     """Regression of data."""
-    x_train_cols = tsutils.make_list(x_train_cols)
-    y_train_col = tsutils.make_list(y_train_col)
     for to in y_train_col:
         for fro in x_train_cols:
             if to == fro:
@@ -263,9 +273,10 @@ keywords.  Instead you have "{to}" in both.
                 )
 
     tsd = tsutils.common_kwds(
-        tsutils.read_iso_ts(
-            input_ts, skiprows=skiprows, names=names, index_type=index_type
-        ),
+        input_ts,
+        skiprows=skiprows,
+        names=names,
+        index_type=index_type,
         start_date=start_date,
         end_date=end_date,
         pick=columns,
@@ -280,6 +291,23 @@ keywords.  Instead you have "{to}" in both.
         ntsd = tsd
     ntsd = tsutils.asbestfreq(ntsd)
 
+    tmplist = []
+    for cols in x_train_cols:
+        if cols == 0 or cols == ntsd.index.name:
+            tmplist.append(len(ntsd.columns) + 1)
+        else:
+            tmplist.append(cols)
+
+    try:
+        # In case ntsd.index.freqstr is a multiple, for example "15T".
+        ntsd[ntsd.index.name + "_"] = (ntsd.index - ntsd.index[0]) // pd.Timedelta(
+            ntsd.index.freqstr
+        )
+    except ValueError:
+        ntsd[ntsd.index.name + "_"] = (ntsd.index - ntsd.index[0]) // pd.Timedelta(
+            "1" + ntsd.index.freqstr
+        )
+
     if x_pred_cols is None:
         nx_pred_cols = x_train_cols
     else:
@@ -287,6 +315,7 @@ keywords.  Instead you have "{to}" in both.
 
     x_train_cols = tsutils.make_iloc(ntsd.columns, x_train_cols)
     y_train_col = tsutils.make_iloc(ntsd.columns, y_train_col)
+
     wtsd = ntsd.iloc[:, x_train_cols + y_train_col]
 
     # Train on 'any' dropna
