@@ -32,6 +32,7 @@ from .functions.expanding_window import expanding_window
 from .functions.fill import fill
 from .functions.filter import filter
 from .functions.fit import fit
+from .functions.forecast import automatic
 from .functions.gof import gof
 from .functions.lag import lag
 from .functions.normalization import normalization
@@ -68,4 +69,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    main
